<?php

namespace Bixo\Leads\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Bixo\Leads\Http\Requests\LeadUserRequest;
use Bixo\Leads\Interfaces\LeadUserRepositoryInterface;
use Bixo\Leads\Models\LeadUser;

/**
 * Resource controller class for lead_user.
 */
class LeadUserResourceController extends BaseController
{

    /**
     * Initialize lead_user resource controller.
     *
     * @param type LeadUserRepositoryInterface $lead_user
     *
     * @return null
     */
    public function __construct(LeadUserRepositoryInterface $lead_user)
    {
        parent::__construct();
        $this->repository = $lead_user;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Leads\Repositories\Criteria\LeadUserResourceCriteria::class);
    }

    /**
     * Display a list of lead_user.
     *
     * @return Response
     */
    public function index(LeadUserRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Bixo\Leads\Repositories\Presenter\LeadUserPresenter::class)
                ->$function();
        }

        $lead_users = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('leads::lead_user.names'))
            ->view('leads::lead_user.index', true)
            ->data(compact('lead_users', 'view'))
            ->output();
    }

    /**
     * Display lead_user.
     *
     * @param Request $request
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function show(LeadUserRequest $request, LeadUser $lead_user)
    {

        if ($lead_user->exists) {
            $view = 'leads::lead_user.show';
        } else {
            $view = 'leads::lead_user.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('leads::lead_user.name'))
            ->data(compact('lead_user'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new lead_user.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LeadUserRequest $request)
    {

        $lead_user = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('leads::lead_user.name')) 
            ->view('leads::lead_user.create', true) 
            ->data(compact('lead_user'))
            ->output();
    }

    /**
     * Create new lead_user.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeadUserRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $lead_user                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('leads::lead_user.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leads/lead_user/' . $lead_user->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/leads/lead_user'))
                ->redirect();
        }

    }

    /**
     * Show lead_user for editing.
     *
     * @param Request $request
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function edit(LeadUserRequest $request, LeadUser $lead_user)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('leads::lead_user.name'))
            ->view('leads::lead_user.edit', true)
            ->data(compact('lead_user'))
            ->output();
    }

    /**
     * Update the lead_user.
     *
     * @param Request $request
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function update(LeadUserRequest $request, LeadUser $lead_user)
    {
        try {
            $attributes = $request->all();

            $lead_user->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('leads::lead_user.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leads/lead_user/' . $lead_user->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leads/lead_user/' . $lead_user->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the lead_user.
     *
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function destroy(LeadUserRequest $request, LeadUser $lead_user)
    {
        try {

            $lead_user->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leads::lead_user.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('leads/lead_user/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leads/lead_user/' . $lead_user->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple lead_user.
     *
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function delete(LeadUserRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leads::lead_user.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('leads/lead_user'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leads/lead_user'))
                ->redirect();
        }

    }

    /**
     * Restore deleted lead_users.
     *
     * @param Model   $lead_user
     *
     * @return Response
     */
    public function restore(LeadUserRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('leads::lead_user.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/leads/lead_user'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leads/lead_user/'))
                ->redirect();
        }

    }

}
